==> iaxmodem_1.1.1~dfsg.orig.tar.gz: iaxmodem-1.1.1/lib/spandsp/src/v27ter_rx_4800_floating_rrc.h <==
#define PULSESHAPER_4800_GAIN        1.000000f
#define PULSESHAPER_4800_COEFF_SETS  8
static const complexf_t pulseshaper_4800[PULSESHAPER_4800_COEFF_SETS][27] =
{
    {
        {  -0.0033256218f,   -0.0016944890f},     /* Filter 0 */
        {   0.0009305771f,   -0.0028640219f},
        {  -0.0015971835f,   -0.0002529690f},
        {   0.0000000000f,   -0.0071280394f},
        {   0.0079803629f,   -0.0012639653f},
        {   0.0000856199f,    0.0002635111f},
        {   0.0134186592f,   -0.0068371484f},
        {   0.0173489890f,    0.0238788348f},
        {  -0.0212482252f,    0.0212482252f},
        {  -0.0043725352f,   -0.0031768328f},
        {  -0.0212278148f,    0.0416619324f},
        {  -0.1104697471f,   -0.0358937967f},
        {   0.0285220984f,   -0.1800814422f},
        {   0.2227359376f,    0.0000000000f},
        {   0.0348435773f,    0.2199936886f},
        {  -0.1734025016f,    0.0563418882f},
        {  -0.0527331603f,   -0.1034946543f},
        {   0.0378282430f,   -0.0274838273f},
        {  -0.0038217359f,   -0.0038217359f},
        {   0.0176626696f,   -0.0243105791f},
        {   0.0262988265f,    0.0133999214f},
        {  -0.0046538310f,    0.0143230189f},
        {   0.0002736608f,    0.0000433436f},
        {   0.0000000000f,    0.0080798392f},
        {  -0.0070402814f,    0.0011150710f},
        {  -0.0004997091f,   -0.0015379465f},
        {  -0.0026831867f,    0.0013671519f}
    },
    {
        {  -0.0034458238f,   -0.0017557349f},     /* Filter 1 */
        {   0.0008096319f,   -0.0024917908f},
        {  -0.0023281305f,   -0.0003687396f},
        {   0.0000000000f,   -0.0076128677f},
        {   0.0075308694f,   -0.0011927725f},
        {  -0.0004118109f,   -0.0012674236f},
        {   0.0152885238f,   -0.0077898920f},
        {   0.0179999198f,    0.0247747642f},
        {  -0.0201560074f,    0.0201560073f},
        {  -0.0002450506f,   -0.0001780397f},
        {  -0.0248951628f,    0.0488595080f},
        {  -0.1189640874f,   -0.0386537751f},
        {   0.0295975058f,   -0.1868712970f},
        {   0.2251016174f,    0.0000000000f},
        {   0.0343715984f,    0.2170137312f},
        {  -0.1664714744f,    0.0540898609f},
        {  -0.0486568478f,   -0.0954944407f},
        {   0.0315222376f,   -0.0229022462f},
        {  -0.0071130021f,   -0.0071130021f},
        {   0.0183322510f,   -0.0252321788f},
        {   0.0251163790f,    0.0127974343f},
        {  -0.0040031308f,    0.0123203697f},
        {   0.0017373694f,    0.0002751723f},
        {   0.0000000000f,    0.0083907693f},
        {  -0.0064895990f,    0.0010278515f},
        {  -0.0002763861f,   -0.0008506290f},
        {  -0.0029729852f,    0.0015148116f}
    },
    {
        {  -0.0035131448f,   -0.0017900367f},     /* Filter 2 */
        {   0.0006690952f,   -0.0020592633f},
        {  -0.0030664478f,   -0.0004856776f},
        {   0.0000000000f,   -0.0080135090f},
        {   0.0069350877f,   -0.0010984100f},
        {  -0.0009454877f,   -0.0029099119f},
        {   0.0171306792f,   -0.0087285170f},
        {   0.0185057200f,    0.0254709384f},
        {  -0.0187663603f,    0.0187663602f},
        {   0.0042370446f,    0.0030783931f},
        {  -0.0286756337f,    0.0562791000f},
        {  -0.1273684894f,   -0.0413845309f},
        {   0.0306020346f,   -0.1932136421f},
        {   0.2268016406f,    0.0000000000f},
        {   0.0338005382f,    0.2134081993f},
        {  -0.1591873153f,    0.0517230941f},
        {  -0.0445801870f,   -0.0874935433f},
        {   0.0254709341f,   -0.0185057168f},
        {  -0.0100839969f,   -0.0100839969f},
        {   0.0187737877f,   -0.0258399020f},
        {   0.0237628386f,    0.0121077710f},
        {  -0.0033572432f,    0.0103325321f},
        {   0.0030664735f,    0.0004856817f},
        {   0.0000000000f,    0.0085629052f},
        {  -0.0058786966f,    0.0009310941f},
        {  -0.0000612735f,   -0.0001885803f},
        {  -0.0032022929f,    0.0016316497f}
    },
    {
        {  -0.0035245124f,   -0.0017958288f},     /* Filter 3 */
        {   0.0005101233f,   -0.0015699981f},
        {  -0.0038017456f,   -0.0006021373f},
        {   0.0000000000f,   -0.0083189193f},
        {   0.0061906444f,   -0.0009805017f},
        {  -0.0015115772f,   -0.0046521564f},
        {   0.0189227445f,   -0.0096416199f},
        {   0.0188507571f,    0.0259458413f},
        {  -0.0170703338f,    0.0170703338f},
        {   0.0090637512f,    0.0065852007f},
        {  -0.0325525585f,    0.0638879934f},
        {  -0.1356378526f,   -0.0440714099f},
        {   0.0315298182f,   -0.1990714373f},
        {   0.2278257713f,    0.0000000000f},
        {   0.0331338197f,    0.2091987041f},
        {  -0.1515915567f,    0.0492550826f},
        {  -0.0405239110f,   -0.0795326534f},
        {   0.0196974299f,   -0.0143110205f},
        {  -0.0127330841f,   -0.0127330840f},
        {   0.0189988021f,   -0.0261496077f},
        {   0.0222629772f,    0.0113435535f},
        {  -0.0027227278f,    0.0083796945f},
        {   0.0042544823f,    0.0006738438f},
        {   0.0000000000f,    0.0086029159f},
        {  -0.0052193006f,    0.0008266560f},
        {   0.0001430276f,    0.0004401936f},
        {  -0.0033704179f,    0.0017173137f}
    },
    {
        {  -0.0034775081f,   -0.0017718789f},     /* Filter 4 */
        {   0.0003341791f,   -0.0010284976f},
        {  -0.0045231271f,   -0.0007163930f},
        {   0.0000000000f,   -0.0085186340f},
        {   0.0052967893f,   -0.0008389290f},
        {  -0.0021056563f,   -0.0064805437f},
        {   0.0206414817f,   -0.0105173602f},
        {   0.0190199255f,    0.0261786816f},
        {  -0.0150609085f,    0.0150609085f},
        {   0.0142223501f,    0.0103331422f},
        {  -0.0365082065f,    0.0716513895f},
        {  -0.1437270842f,   -0.0466997606f},
        {   0.0323754130f,   -0.2044103127f},
        {   0.2281678478f,    0.0000000000f},
        {   0.0323754130f,    0.2044103127f},
        {  -0.1437270842f,    0.0466997606f},
        {  -0.0365082065f,   -0.0716513895f},
        {   0.0142223501f,   -0.0103331422f},
        {  -0.0150609085f,   -0.0150609085f},
        {   0.0190199255f,   -0.0261786816f},
        {   0.0206414817f,    0.0105173602f},
        {  -0.0021056563f,    0.0064805437f},
        {   0.0052967893f,    0.0008389290f},
        {   0.0000000000f,    0.0085186340f},
        {  -0.0045231271f,    0.0007163930f},
        {   0.0003341791f,    0.0010284976f},
        {  -0.0034775081f,    0.0017718789f}
    },
    {
        {  -0.0033704179f,   -0.0017173137f},     /* Filter 5 */
        {   0.0001430276f,   -0.0004401936f},
        {  -0.0052193006f,   -0.0008266560f},
        {   0.0000000000f,   -0.0086029159f},
        {   0.0042544823f,   -0.0006738438f},
        {  -0.0027227278f,   -0.0083796945f},
        {   0.0222629772f,   -0.0113435535f},
        {   0.0189988021f,    0.0261496077f},
        {  -0.0127330840f,    0.0127330840f},
        {   0.0196974299f,    0.0143110205f},
        {  -0.0405239110f,    0.0795326534f},
        {  -0.1515915567f,   -0.0492550826f},
        {   0.0331338197f,   -0.2091987041f},
        {   0.2278257713f,    0.0000000000f},
        {   0.0315298182f,    0.1990714373f},
        {  -0.1356378526f,    0.0440714099f},
        {  -0.0325525585f,   -0.0638879934f},
        {   0.0090637512f,   -0.0065852007f},
        {  -0.0170703338f,   -0.0170703338f},
        {   0.0188507571f,   -0.0259458413f},
        {   0.0189227445f,    0.0096416199f},
        {  -0.0015115772f,    0.0046521564f},
        {   0.0061906444f,    0.0009805017f},
        {   0.0000000000f,    0.0083189193f},
        {  -0.0038017456f,    0.0006021373f},
        {   0.0005101233f,    0.0015699981f},
        {  -0.0035245124f,    0.0017958288f}
    },
    {
        {  -0.0032022929f,   -0.0016316497f},     /* Filter 6 */
        {  -0.0000612735f,    0.0001885803f},
        {  -0.0058786966f,   -0.0009310941f},
        {   0.0000000000f,   -0.0085629052f},
        {   0.0030664735f,   -0.0004856817f},
        {  -0.0033572432f,   -0.0103325321f},
        {   0.0237628386f,   -0.0121077710f},
        {   0.0187737877f,    0.0258399020f},
        {  -0.0100839969f,    0.0100839969f},
        {   0.0254709341f,    0.0185057168f},
        {  -0.0445801870f,    0.0874935433f},
        {  -0.1591873153f,   -0.0517230941f},
        {   0.0338005382f,   -0.2134081993f},
        {   0.2268016406f,    0.0000000000f},
        {   0.0306020346f,    0.1932136421f},
        {  -0.1273684894f,    0.0413845309f},
        {  -0.0286756337f,   -0.0562791000f},
        {   0.0042370446f,   -0.0030783931f},
        {  -0.0187663603f,   -0.0187663602f},
        {   0.0185057200f,   -0.0254709384f},
        {   0.0171306792f,    0.0087285170f},
        {  -0.0009454877f,    0.0029099119f},
        {   0.0069350877f,    0.0010984100f},
        {   0.0000000000f,    0.0080135090f},
        {  -0.0030664478f,    0.0004856776f},
        {   0.0006690952f,    0.0020592633f},
        {  -0.0035131448f,    0.0017900367f}
    },
    {
        {  -0.0029729852f,   -0.0015148116f},     /* Filter 7 */
        {  -0.0002763861f,    0.0008506290f},
        {  -0.0064895990f,   -0.0010278515f},
        {   0.0000000000f,   -0.0083907693f},
        {   0.0017373694f,   -0.0002751723f},
        {  -0.0040031308f,   -0.0123203697f},
        {   0.0251163790f,   -0.0127974343f},
        {   0.0183322510f,    0.0252321788f},
        {  -0.0071130021f,    0.0071130021f},
        {   0.0315222376f,    0.0229022462f},
        {  -0.0486568478f,    0.0954944407f},
        {  -0.1664714744f,   -0.0540898609f},
        {   0.0343715984f,   -0.2170137312f},
        {   0.2251016174f,    0.0000000000f},
        {   0.0295975058f,    0.1868712970f},
        {  -0.1189640874f,    0.0386537751f},
        {  -0.0248951628f,   -0.0488595080f},
        {  -0.0002450506f,    0.0001780397f},
        {  -0.0201560074f,   -0.0201560073f},
        {   0.0179999198f,   -0.0247747642f},
        {   0.0152885238f,    0.0077898920f},
        {  -0.0004118109f,    0.0012674236f},
        {   0.0075308694f,    0.0011927725f},
        {   0.0000000000f,    0.0076128677f},
        {  -0.0023281305f,    0.0003687396f},
        {   0.0008096319f,    0.0024917908f},
        {  -0.0034458238f,    0.0017557349f}
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v27ter_rx_4800_floating_rrc.h <==
#define RX_PULSESHAPER_4800_GAIN        1.000000f
#define RX_PULSESHAPER_4800_COEFF_SETS  8
static const complexf_t rx_pulseshaper_4800[RX_PULSESHAPER_4800_COEFF_SETS][27] =
{
    {
        {  -0.0033256218f,   -0.0016944890f},     /* Filter 0 */
        {   0.0009305771f,   -0.0028640219f},
        {  -0.0015971835f,   -0.0002529690f},
        {   0.0000000000f,   -0.0071280394f},
        {   0.0079803629f,   -0.0012639653f},
        {   0.0000856199f,    0.0002635111f},
        {   0.0134186592f,   -0.0068371484f},
        {   0.0173489890f,    0.0238788348f},
        {  -0.0212482252f,    0.0212482252f},
        {  -0.0043725352f,   -0.0031768328f},
        {  -0.0212278148f,    0.0416619324f},
        {  -0.1104697471f,   -0.0358937967f},
        {   0.0285220984f,   -0.1800814422f},
        {   0.2227359376f,    0.0000000000f},
        {   0.0348435773f,    0.2199936886f},
        {  -0.1734025016f,    0.0563418882f},
        {  -0.0527331603f,   -0.1034946543f},
        {   0.0378282430f,   -0.0274838273f},
        {  -0.0038217359f,   -0.0038217359f},
        {   0.0176626696f,   -0.0243105791f},
        {   0.0262988265f,    0.0133999214f},
        {  -0.0046538310f,    0.0143230189f},
        {   0.0002736608f,    0.0000433436f},
        {   0.0000000000f,    0.0080798392f},
        {  -0.0070402814f,    0.0011150710f},
        {  -0.0004997091f,   -0.0015379465f},
        {  -0.0026831867f,    0.0013671519f}
    },
    {
        {  -0.0034458238f,   -0.0017557349f},     /* Filter 1 */
        {   0.0008096319f,   -0.0024917908f},
        {  -0.0023281305f,   -0.0003687396f},
        {   0.0000000000f,   -0.0076128677f},
        {   0.0075308694f,   -0.0011927725f},
        {  -0.0004118109f,   -0.0012674236f},
        {   0.0152885238f,   -0.0077898920f},
        {   0.0179999198f,    0.0247747642f},
        {  -0.0201560074f,    0.0201560073f},
        {  -0.0002450506f,   -0.0001780397f},
        {  -0.0248951628f,    0.0488595080f},
        {  -0.1189640874f,   -0.0386537751f},
        {   0.0295975058f,   -0.1868712970f},
        {   0.2251016174f,    0.0000000000f},
        {   0.0343715984f,    0.2170137312f},
        {  -0.1664714744f,    0.0540898609f},
        {  -0.0486568478f,   -0.0954944407f},
        {   0.0315222376f,   -0.0229022462f},
        {  -0.0071130021f,   -0.0071130021f},
        {   0.0183322510f,   -0.0252321788f},
        {   0.0251163790f,    0.0127974343f},
        {  -0.0040031308f,    0.0123203697f},
        {   0.0017373694f,    0.0002751723f},
        {   0.0000000000f,    0.0083907693f},
        {  -0.0064895990f,    0.0010278515f},
        {  -0.0002763861f,   -0.0008506290f},
        {  -0.0029729852f,    0.0015148116f}
    },
    {
        {  -0.0035131448f,   -0.0017900367f},     /* Filter 2 */
        {   0.0006690952f,   -0.0020592633f},
        {  -0.0030664478f,   -0.0004856776f},
        {   0.0000000000f,   -0.0080135090f},
        {   0.0069350877f,   -0.0010984100f},
        {  -0.0009454877f,   -0.0029099119f},
        {   0.0171306792f,   -0.0087285170f},
        {   0.0185057200f,    0.0254709384f},
        {  -0.0187663603f,    0.0187663602f},
        {   0.0042370446f,    0.0030783931f},
        {  -0.0286756337f,    0.0562791000f},
        {  -0.1273684894f,   -0.0413845309f},
        {   0.0306020346f,   -0.1932136421f},
        {   0.2268016406f,    0.0000000000f},
        {   0.0338005382f,    0.2134081993f},
        {  -0.1591873153f,    0.0517230941f},
        {  -0.0445801870f,   -0.0874935433f},
        {   0.0254709341f,   -0.0185057168f},
        {  -0.0100839969f,   -0.0100839969f},
        {   0.0187737877f,   -0.0258399020f},
        {   0.0237628386f,    0.0121077710f},
        {  -0.0033572432f,    0.0103325321f},
        {   0.0030664735f,    0.0004856817f},
        {   0.0000000000f,    0.0085629052f},
        {  -0.0058786966f,    0.0009310941f},
        {  -0.0000612735f,   -0.0001885803f},
        {  -0.0032022929f,    0.0016316497f}
    },
    {
        {  -0.0035245124f,   -0.0017958288f},     /* Filter 3 */
        {   0.0005101233f,   -0.0015699981f},
        {  -0.0038017456f,   -0.0006021373f},
        {   0.0000000000f,   -0.0083189193f},
        {   0.0061906444f,   -0.0009805017f},
        {  -0.0015115772f,   -0.0046521564f},
        {   0.0189227445f,   -0.0096416199f},
        {   0.0188507571f,    0.0259458413f},
        {  -0.0170703338f,    0.0170703338f},
        {   0.0090637512f,    0.0065852007f},
        {  -0.0325525585f,    0.0638879934f},
        {  -0.1356378526f,   -0.0440714099f},
        {   0.0315298182f,   -0.1990714373f},
        {   0.2278257713f,    0.0000000000f},
        {   0.0331338197f,    0.2091987041f},
        {  -0.1515915567f,    0.0492550826f},
        {  -0.0405239110f,   -0.0795326534f},
        {   0.0196974299f,   -0.0143110205f},
        {  -0.0127330841f,   -0.0127330840f},
        {   0.0189988021f,   -0.0261496077f},
        {   0.0222629772f,    0.0113435535f},
        {  -0.0027227278f,    0.0083796945f},
        {   0.0042544823f,    0.0006738438f},
        {   0.0000000000f,    0.0086029159f},
        {  -0.0052193006f,    0.0008266560f},
        {   0.0001430276f,    0.0004401936f},
        {  -0.0033704179f,    0.0017173137f}
    },
    {
        {  -0.0034775081f,   -0.0017718789f},     /* Filter 4 */
        {   0.0003341791f,   -0.0010284976f},
        {  -0.0045231271f,   -0.0007163930f},
        {   0.0000000000f,   -0.0085186340f},
        {   0.0052967893f,   -0.0008389290f},
        {  -0.0021056563f,   -0.0064805437f},
        {   0.0206414817f,   -0.0105173602f},
        {   0.0190199255f,    0.0261786816f},
        {  -0.0150609085f,    0.0150609085f},
        {   0.0142223501f,    0.0103331422f},
        {  -0.0365082065f,    0.0716513895f},
        {  -0.1437270842f,   -0.0466997606f},
        {   0.0323754130f,   -0.2044103127f},
        {   0.2281678478f,    0.0000000000f},
        {   0.0323754130f,    0.2044103127f},
        {  -0.1437270842f,    0.0466997606f},
        {  -0.0365082065f,   -0.0716513895f},
        {   0.0142223501f,   -0.0103331422f},
        {  -0.0150609085f,   -0.0150609085f},
        {   0.0190199255f,   -0.0261786816f},
        {   0.0206414817f,    0.0105173602f},
        {  -0.0021056563f,    0.0064805437f},
        {   0.0052967893f,    0.0008389290f},
        {   0.0000000000f,    0.0085186340f},
        {  -0.0045231271f,    0.0007163930f},
        {   0.0003341791f,    0.0010284976f},
        {  -0.0034775081f,    0.0017718789f}
    },
    {
        {  -0.0033704179f,   -0.0017173137f},     /* Filter 5 */
        {   0.0001430276f,   -0.0004401936f},
        {  -0.0052193006f,   -0.0008266560f},
        {   0.0000000000f,   -0.0086029159f},
        {   0.0042544823f,   -0.0006738438f},
        {  -0.0027227278f,   -0.0083796945f},
        {   0.0222629772f,   -0.0113435535f},
        {   0.0189988021f,    0.0261496077f},
        {  -0.0127330840f,    0.0127330840f},
        {   0.0196974299f,    0.0143110205f},
        {  -0.0405239110f,    0.0795326534f},
        {  -0.1515915567f,   -0.0492550826f},
        {   0.0331338197f,   -0.2091987041f},
        {   0.2278257713f,    0.0000000000f},
        {   0.0315298182f,    0.1990714373f},
        {  -0.1356378526f,    0.0440714099f},
        {  -0.0325525585f,   -0.0638879934f},
        {   0.0090637512f,   -0.0065852007f},
        {  -0.0170703338f,   -0.0170703338f},
        {   0.0188507571f,   -0.0259458413f},
        {   0.0189227445f,    0.0096416199f},
        {  -0.0015115772f,    0.0046521564f},
        {   0.0061906444f,    0.0009805017f},
        {   0.0000000000f,    0.0083189193f},
        {  -0.0038017456f,    0.0006021373f},
        {   0.0005101233f,    0.0015699981f},
        {  -0.0035245124f,    0.0017958288f}
    },
    {
        {  -0.0032022929f,   -0.0016316497f},     /* Filter 6 */
        {  -0.0000612735f,    0.0001885803f},
        {  -0.0058786966f,   -0.0009310941f},
        {   0.0000000000f,   -0.0085629052f},
        {   0.0030664735f,   -0.0004856817f},
        {  -0.0033572432f,   -0.0103325321f},
        {   0.0237628386f,   -0.0121077710f},
        {   0.0187737877f,    0.0258399020f},
        {  -0.0100839969f,    0.0100839969f},
        {   0.0254709341f,    0.0185057168f},
        {  -0.0445801870f,    0.0874935433f},
        {  -0.1591873153f,   -0.0517230941f},
        {   0.0338005382f,   -0.2134081993f},
        {   0.2268016406f,    0.0000000000f},
        {   0.0306020346f,    0.1932136421f},
        {  -0.1273684894f,    0.0413845309f},
        {  -0.0286756337f,   -0.0562791000f},
        {   0.0042370446f,   -0.0030783931f},
        {  -0.0187663603f,   -0.0187663602f},
        {   0.0185057200f,   -0.0254709384f},
        {   0.0171306792f,    0.0087285170f},
        {  -0.0009454877f,    0.0029099119f},
        {   0.0069350877f,    0.0010984100f},
        {   0.0000000000f,    0.0080135090f},
        {  -0.0030664478f,    0.0004856776f},
        {   0.0006690952f,    0.0020592633f},
        {  -0.0035131448f,    0.0017900367f}
    },
    {
        {  -0.0029729852f,   -0.0015148116f},     /* Filter 7 */
        {  -0.0002763861f,    0.0008506290f},
        {  -0.0064895990f,   -0.0010278515f},
        {   0.0000000000f,   -0.0083907693f},
        {   0.0017373694f,   -0.0002751723f},
        {  -0.0040031308f,   -0.0123203697f},
        {   0.0251163790f,   -0.0127974343f},
        {   0.0183322510f,    0.0252321788f},
        {  -0.0071130021f,    0.0071130021f},
        {   0.0315222376f,    0.0229022462f},
        {  -0.0486568478f,    0.0954944407f},
        {  -0.1664714744f,   -0.0540898609f},
        {   0.0343715984f,   -0.2170137312f},
        {   0.2251016174f,    0.0000000000f},
        {   0.0295975058f,    0.1868712970f},
        {  -0.1189640874f,    0.0386537751f},
        {  -0.0248951628f,   -0.0488595080f},
        {  -0.0002450506f,    0.0001780397f},
        {  -0.0201560074f,   -0.0201560073f},
        {   0.0179999198f,   -0.0247747642f},
        {   0.0152885238f,    0.0077898920f},
        {  -0.0004118109f,    0.0012674236f},
        {   0.0075308694f,    0.0011927725f},
        {   0.0000000000f,    0.0076128677f},
        {  -0.0023281305f,    0.0003687396f},
        {   0.0008096319f,    0.0024917908f},
        {  -0.0034458238f,    0.0017557349f}
    }
};
